@@ -3,9 +3,9 @@
 /*
  +-----------------------------------------------------------------------+
  | Roundcube Webmail IMAP Client                                         |
- | Version 1.3.6                                                         |
+ | Version 1.5.12                                                         |
  |                                                                       |
- | Copyright (C) 2005-2017, The Roundcube Dev Team                       |
+ | Copyright (C) The Roundcube Dev Team                                  |
  |                                                                       |
  | Licensed under the GNU General Public License version 3 or            |
  | any later version with exceptions for skins & plugins.                |
@@ -13,7 +13,7 @@
  |                                                                       |
  | PURPOSE:                                                              |
  |   This is the public entry point for all HTTP requests to the         |
- |   Roundcue webmail application.                                       |
+ |   Roundcube webmail application.                                      |
  +-----------------------------------------------------------------------+
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  | Author: Aleksander Machniak <alec@alec.pl>                            |
@@ -24,4 +24,3 @@ define('INSTALL_PATH', realpath(__DIR__ . '/..') . '/');
 
 // include index.php from application root directory
 include INSTALL_PATH . 'index.php';
-
